BaseWWTWidget
=============

.. currentmodule:: pywwt.core

.. autoclass:: BaseWWTWidget
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~BaseWWTWidget.actual_planet_scale
      ~BaseWWTWidget.alt_az_grid
      ~BaseWWTWidget.available_hips_catalog_names
      ~BaseWWTWidget.available_layers
      ~BaseWWTWidget.available_views
      ~BaseWWTWidget.background
      ~BaseWWTWidget.constellation_boundaries
      ~BaseWWTWidget.constellation_boundary_color
      ~BaseWWTWidget.constellation_figure_color
      ~BaseWWTWidget.constellation_figures
      ~BaseWWTWidget.constellation_selection
      ~BaseWWTWidget.constellation_selection_color
      ~BaseWWTWidget.crosshairs
      ~BaseWWTWidget.crosshairs_color
      ~BaseWWTWidget.current_mode
      ~BaseWWTWidget.ecliptic
      ~BaseWWTWidget.ecliptic_grid
      ~BaseWWTWidget.foreground
      ~BaseWWTWidget.foreground_opacity
      ~BaseWWTWidget.galactic_grid
      ~BaseWWTWidget.galactic_mode
      ~BaseWWTWidget.grid
      ~BaseWWTWidget.imagery
      ~BaseWWTWidget.instruments
      ~BaseWWTWidget.layers
      ~BaseWWTWidget.local_horizon_mode
      ~BaseWWTWidget.location_altitude
      ~BaseWWTWidget.location_latitude
      ~BaseWWTWidget.location_longitude
      ~BaseWWTWidget.most_recent_source
      ~BaseWWTWidget.selected_sources
      ~BaseWWTWidget.solar_system

   .. rubric:: Methods Summary

   .. autosummary::

      ~BaseWWTWidget.add_circle
      ~BaseWWTWidget.add_collection
      ~BaseWWTWidget.add_fov
      ~BaseWWTWidget.add_line
      ~BaseWWTWidget.add_polygon
      ~BaseWWTWidget.becomes_ready
      ~BaseWWTWidget.center_on_coordinates
      ~BaseWWTWidget.clear_annotations
      ~BaseWWTWidget.get_center
      ~BaseWWTWidget.get_current_time
      ~BaseWWTWidget.get_fov
      ~BaseWWTWidget.load_image_collection
      ~BaseWWTWidget.load_tour
      ~BaseWWTWidget.pause_time
      ~BaseWWTWidget.pause_tour
      ~BaseWWTWidget.play_time
      ~BaseWWTWidget.reset
      ~BaseWWTWidget.reset_view
      ~BaseWWTWidget.resume_tour
      ~BaseWWTWidget.save_as_html_bundle
      ~BaseWWTWidget.set_current_time
      ~BaseWWTWidget.set_selection_change_callback
      ~BaseWWTWidget.set_view

   .. rubric:: Attributes Documentation

   .. autoattribute:: actual_planet_scale
   .. autoattribute:: alt_az_grid
   .. autoattribute:: available_hips_catalog_names
   .. autoattribute:: available_layers
   .. autoattribute:: available_views
   .. autoattribute:: background
   .. autoattribute:: constellation_boundaries
   .. autoattribute:: constellation_boundary_color
   .. autoattribute:: constellation_figure_color
   .. autoattribute:: constellation_figures
   .. autoattribute:: constellation_selection
   .. autoattribute:: constellation_selection_color
   .. autoattribute:: crosshairs
   .. autoattribute:: crosshairs_color
   .. autoattribute:: current_mode
   .. autoattribute:: ecliptic
   .. autoattribute:: ecliptic_grid
   .. autoattribute:: foreground
   .. autoattribute:: foreground_opacity
   .. autoattribute:: galactic_grid
   .. autoattribute:: galactic_mode
   .. autoattribute:: grid
   .. autoattribute:: imagery
   .. autoattribute:: instruments
   .. autoattribute:: layers
   .. autoattribute:: local_horizon_mode
   .. autoattribute:: location_altitude
   .. autoattribute:: location_latitude
   .. autoattribute:: location_longitude
   .. autoattribute:: most_recent_source
   .. autoattribute:: selected_sources
   .. autoattribute:: solar_system

   .. rubric:: Methods Documentation

   .. automethod:: add_circle
   .. automethod:: add_collection
   .. automethod:: add_fov
   .. automethod:: add_line
   .. automethod:: add_polygon
   .. automethod:: becomes_ready
   .. automethod:: center_on_coordinates
   .. automethod:: clear_annotations
   .. automethod:: get_center
   .. automethod:: get_current_time
   .. automethod:: get_fov
   .. automethod:: load_image_collection
   .. automethod:: load_tour
   .. automethod:: pause_time
   .. automethod:: pause_tour
   .. automethod:: play_time
   .. automethod:: reset
   .. automethod:: reset_view
   .. automethod:: resume_tour
   .. automethod:: save_as_html_bundle
   .. automethod:: set_current_time
   .. automethod:: set_selection_change_callback
   .. automethod:: set_view
